vld1_p64

Function vld1_p64 

1.59.0 · Source
pub unsafe fn vld1_p64(ptr: *const u64) -> poly64x1_t
Available on target feature aes and target feature neon and (AArch64 or ARM64EC) only.
This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).
Load multiple single-element structures to one, two, three, or four registers Arm’s documentation

Safety

  • Neon intrinsic unsafe